bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDToGaussianWishart
======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoclass:: GaussianGammaARDToGaussianWishart

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGammaARDToGaussianWishart.__init__
      ~GaussianGammaARDToGaussianWishart.add_plate_axis
      ~GaussianGammaARDToGaussianWishart.broadcasting_multiplier
      ~GaussianGammaARDToGaussianWishart.delete
      ~GaussianGammaARDToGaussianWishart.get_mask
      ~GaussianGammaARDToGaussianWishart.get_moments
      ~GaussianGammaARDToGaussianWishart.get_shape
      ~GaussianGammaARDToGaussianWishart.has_plotter
      ~GaussianGammaARDToGaussianWishart.lower_bound_contribution
      ~GaussianGammaARDToGaussianWishart.move_plates
      ~GaussianGammaARDToGaussianWishart.plot
      ~GaussianGammaARDToGaussianWishart.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGammaARDToGaussianWishart.plates
      ~GaussianGammaARDToGaussianWishart.plates_multiplier
   
   